@@ -42,6 +42,7 @@ typedef struct {
   SCM get_options_lambda;
   SCM apply_options_lambda;
   SCM timeout_lambda;
+  SCM droppable_lambda;
 } lambda_data;
 
 lambda_data* game_data = NULL;
@@ -57,11 +58,11 @@ void add_slot(SCM slot_data)
   hslot->x = scm_num2dbl (SCM_CAR(SCM_CADR(SCM_CADDR(slot_data))), NULL);
   hslot->y = scm_num2dbl (SCM_CADR(SCM_CADR(SCM_CADDR(slot_data))), NULL);
   
-  hslot->dx = hslot->dy = 0;
+  hslot->dx = hslot->dy = hslot->compressed_dy = 0;
   hslot->expansion_depth = 0;
 
   if (!strcmp("expanded", SCM_CHARS(SCM_CAR(SCM_CADDR(slot_data))))) {
-    hslot->dy = y_expanded_offset;
+    hslot->compressed_dy = hslot->dy = y_expanded_offset;
   }
   else if (!strcmp("expanded-right", 
 		   SCM_CHARS(SCM_CAR(SCM_CADDR(slot_data))))) {
@@ -69,7 +70,7 @@ void add_slot(SCM slot_data)
   }
   else if (!strcmp("partially-expanded", 
 		   SCM_CHARS(SCM_CAR(SCM_CADDR(slot_data))))) {
-    hslot->dy = y_expanded_offset;
+    hslot->compressed_dy = hslot->dy = y_expanded_offset;
     hslot->expansion_depth = SCM_INUM (SCM_CADDR(SCM_CADDR(slot_data)));
   }
   else if (!strcmp("partially-expanded-right", 
@@ -158,10 +159,25 @@ static SCM scm_redo_set_sensitive (SCM in_state)
   return SCM_EOL;
 }
 
+static SCM scm_get_feature_word()
+{
+  return SCM_MAKINUM(enabled_features);
+}
+
+static SCM scm_set_feature_word(SCM features)
+{
+  enabled_features = SCM_INUM(features);
+
+  droppable_is_featured = (enabled_features & DROPPABLE_FMASK);
+
+  return SCM_EOL;
+}
+
 static SCM scm_set_statusbar_message(SCM message)
 {
-  gnome_appbar_clear_stack (GNOME_APPBAR (GNOME_APP (app)->statusbar));
-  gnome_appbar_push (GNOME_APPBAR(GNOME_APP (app)->statusbar), _(SCM_STRING_CHARS(message)));
+  guint context_id = gtk_statusbar_get_context_id (GTK_STATUSBAR (statusbar), "message");
+  gtk_statusbar_pop (GTK_STATUSBAR (statusbar), context_id);
+  gtk_statusbar_push (GTK_STATUSBAR (statusbar), context_id, _(SCM_STRING_CHARS(message)));
   return SCM_EOL;
 }
 
@@ -194,7 +210,7 @@ static SCM gg_scm_add_slot(SCM slot)
 static SCM scm_set_slot_y_expansion(SCM scm_slot_id, SCM new_exp_val)
 {
   hslot_type slot = get_slot(scm_num2int(scm_slot_id, SCM_ARG1, NULL));
-  slot->dy = scm_num2dbl (new_exp_val, NULL);
+  slot->compressed_dy = slot->dy = scm_num2dbl (new_exp_val, NULL);
   return SCM_EOL;
 }
 
@@ -257,6 +273,9 @@ static SCM scm_set_lambda(SCM start_game_lambda,
   game_data->apply_options_lambda = SCM_CADR(rest);
   game_data->timeout_lambda = SCM_CADDR(rest);
 
+  if (droppable_is_featured)
+    game_data->droppable_lambda = SCM_CADDDR(rest);
+
   return SCM_EOL;
 }
 
@@ -297,6 +316,8 @@ static SCM scm_get_timeout ()
 
 void cscm_init () 
 {
+  scm_c_define_gsubr("set-feature-word!", 1, 0, 0, scm_set_feature_word);
+  scm_c_define_gsubr("get-feature-word", 0, 0, 0, scm_get_feature_word);
   scm_c_define_gsubr("set-statusbar-message", 1, 0, 0, scm_set_statusbar_message);
   scm_c_define_gsubr("set-surface-layout", 1, 0, 0, scm_set_surface_layout);
   scm_c_define_gsubr("reset-surface", 0, 0, 0, scm_reset_surface);
@@ -329,9 +350,10 @@ typedef struct
 } CallData;
 
 
-static void
-cscmi_call_lambda (CallData *call_data)
+static SCM
+cscmi_call_lambda (void *user_data)
 {
+  CallData *call_data = user_data;
   switch (call_data->n_args)
     {
     case 0:
@@ -349,14 +371,144 @@ cscmi_call_lambda (CallData *call_data)
     default:
       g_assert_not_reached ();
     }
+
+  return SCM_EOL;
 }
 
+extern guint32 seed;
+extern gchar *filename;
+
 static void
+cscmi_write_exception_details (int error_fd,
+			       SCM tag,
+			       SCM throw_args)
+{
+  char *message;
+  SCM port;
+  GList *slots;
+  GList *slot_list;
+
+  message = g_strdup_printf ("Variation: %s\n", filename);
+  write (error_fd, message, strlen (message));
+  g_free (message);
+
+  message = g_strdup_printf ("Seed: %u\n", seed);
+  write (error_fd, message, strlen (message));
+  g_free (message);
+  
+  message = "Scheme error:\n\t";
+  write (error_fd, message, strlen (message));
+
+  port = scm_fdopen (scm_long2num (error_fd),
+		     scm_mem2string ("w", sizeof (char)));
+  scm_display (throw_args, port);
+  scm_fsync (port);
+
+  message = "\nScheme tag:\n\t";
+  write (error_fd, message, strlen (message));
+  scm_display (tag, port);
+  scm_fsync (port);
+
+  message = "\n\nDeck State:\n";
+  write (error_fd, message, strlen (message));
+  slots = get_slot_list ();
+  if (slots)
+    {
+      for (slot_list = slots; slot_list; slot_list = slot_list->next)
+	{
+	  hslot_type slot;
+	  GList *card_list;
+
+	  slot = slot_list->data;
+	  message = g_strdup_printf ("\tSlot %d\n", slot->id);
+	  write (error_fd, message, strlen (message));
+	  g_free (message);
+	  if (slot->cards)
+	    {
+	      int count = 0;
+	      for (card_list = slot->cards; card_list; card_list = card_list->next)
+		{
+		  hcard_type card = card_list->data;
+
+		  if (count == 0)
+		    message = "\t\t";
+		  else
+		    message = ", ";
+		  write (error_fd, message, strlen (message));
+
+		  message = g_strdup_printf ("(%d %d %s)",
+					     card->suit,
+					     card->value,
+					     card->direction ? "#t" : "#f");
+		  write (error_fd, message, strlen (message));
+		  g_free (message);
+		  count ++;
+		  if (count == 5)
+		    {
+		      message = "\n";
+		      write (error_fd, message, strlen (message));
+		      count = 0;
+		    }
+		}
+	      if (count != 0)
+		{
+		  message = "\n";
+		  write (error_fd, message, strlen (message));
+		}
+	    }
+	  else
+	    {
+	      message = "\t\t(Empty)\n";
+	      write (error_fd, message, strlen (message));
+	    }
+	}
+    }
+  else
+    {
+      message = "\tNo cards in deck\n";
+      write (error_fd, message, strlen (message));
+    }
+}
+
+/* Called when we get an exception from guile.  We launch bug-buddy with the
+ * exception information:
+ */
+static SCM
 cscmi_catch_handler (gpointer data,
 		     SCM      tag,
 		     SCM      throw_args)
 {
-  gh_display (throw_args);
+  int error_fd;
+  gchar *error_file;
+  GError *error = NULL;
+  gchar *exec_str;
+
+  error_fd = g_file_open_tmp ("arcrashXXXXXX",
+			      &error_file,
+			      &error);
+  if (error)
+    {
+      GtkWidget *message_dialog;
+
+      message_dialog = gtk_message_dialog_new (NULL,
+					       GTK_DIALOG_DESTROY_WITH_PARENT,
+					       GTK_MESSAGE_ERROR,
+					       GTK_BUTTONS_OK,
+					       _("A scheme exception occured and we were unable to create a temporary file to report it:\n\n%s"),
+					       error->message);
+      gtk_dialog_run (GTK_DIALOG (message_dialog));
+      exit (1);
+    }
+  cscmi_write_exception_details (error_fd, tag, throw_args);
+  close (error_fd);
+
+  exec_str = g_strdup_printf ("bug-buddy --package=gnome-games --package-version=%s --appname=aisleriot --kill=%d --include=%s",
+			      VERSION,
+			      getpid (),
+			      error_file);
+  system (exec_str);
+  unlink (error_file);
+  exit (1);
 }
 
 SCM
@@ -459,6 +611,32 @@ cscmi_button_double_clicked_lambda (SCM slot_id)
   return call_data->retval;
 }
 
+SCM
+cscmi_droppable_lambda (SCM start_slot,
+                        SCM cards,
+                        SCM end_slot)
+{
+  CallData *call_data;
+
+  if (!droppable_is_featured) 
+    return SCM_BOOL_F;
+  
+  call_data = g_new0 (CallData, 1);
+  call_data->lambda = game_data->droppable_lambda;
+  call_data->n_args = 3;
+  call_data->arg1 = start_slot;
+  call_data->arg2 = cards;
+  call_data->arg3 = end_slot;
+  scm_internal_catch (SCM_BOOL_T,
+                      cscmi_call_lambda,
+                      call_data,
+                      cscmi_catch_handler,
+                      NULL);
+  g_free (call_data);
+
+  return call_data->retval;
+}
+
 SCM
 cscmi_game_over_lambda (void)
 {
@@ -517,6 +695,7 @@ SCM
 cscmi_get_options_lambda (void)
 {
   CallData *call_data;
+  SCM retval;
 
   call_data = g_new0 (CallData, 1);
   call_data->lambda = game_data->get_options_lambda;
@@ -526,9 +705,19 @@ cscmi_get_options_lambda (void)
 		      call_data,
 		      cscmi_catch_handler,
 		      NULL);
+  retval = call_data->retval;
   g_free (call_data);
 
-  return call_data->retval;
+  return retval;
+}
+
+gboolean
+has_options (void)
+{
+  SCM options;
+
+  options = cscmi_get_options_lambda ();
+  return SCM_NFALSEP (options);
 }
 
 SCM
