@@ -95,6 +95,11 @@ gboolean move_possible_to(GtkGridBoard * gridboard, int x, int y, int turn) {
 gboolean computer_move_cb(gpointer turn) {
 	move cm;
 
+	/* In case the level gets changed between the timeout
+	 * being set and it going off. */
+	if (props_get_level (GPOINTER_TO_INT (turn)) < 1)
+	  return FALSE;
+
 	cm=computer_move(gridboard, GPOINTER_TO_INT(turn));
 	do_move(cm);
 	return FALSE;
@@ -333,8 +338,12 @@ void undo_move_cb(GtkWidget * widget, gpointer data) {
 }
 
 /* menu: Game->Quit */
-void quit_game_cb(GtkWidget * widget, gpointer data) {
+gboolean quit_game_cb(GtkWidget * widget, gpointer data) {
+        if (timeoutid)
+		g_source_remove (timeoutid);
 	gtk_main_quit();
+	
+	return TRUE;
 }
 
 /* menu: Settings->Preferences */
@@ -361,44 +370,18 @@ apply_changes() {
 void
 about_cb(GtkWidget *widget, gpointer data)
 {
-  static GtkWidget *about;
-  GdkPixbuf *pixbuf = NULL;
   const gchar *authors[] = {"Chris Rogers", "Sjoerd Langkemper", 
 			    N_("Based on code from Iagno by Ian Peters"), NULL};
-  const gchar *documenters[] = { NULL };
-  const gchar *translator_credits = _("translator-credits");
-  gchar *iconfile;
 
-  if (about != NULL) {
-    gtk_window_present (GTK_WINDOW (about));
-    return;
-  }
-
-  iconfile = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_PIXMAP,
-					"gataxx.png", TRUE, NULL);
-  if (iconfile != NULL) {
-    pixbuf = gdk_pixbuf_new_from_file (iconfile, NULL);
-    g_free (iconfile);
-  }
-
-  about = gnome_about_new (_("Ataxx"), VERSION,
-			   "Copyright \xc2\xa9 1999-2003 Chris Rogers\n"
-			   "Copyright \xc2\xa9 2004 Sjoerd Langkemper",
-                          _("A disk-flipping game where you attempt to dominate the board."),
-                          (const char **)authors,
-                          (const char **)documenters,
-                          g_utf8_collate (translator_credits, "translator-credits") !=
-0 ? translator_credits : NULL,
-                          pixbuf);
-
-  if (pixbuf != NULL)
-    gdk_pixbuf_unref (pixbuf);
-  
-  g_signal_connect (G_OBJECT (about), "destroy", 
-		    G_CALLBACK (gtk_widget_destroyed), &about);
-  gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW (window));
-  
-  gtk_widget_show (about);
+  gtk_show_about_dialog (GTK_WINDOW (window),
+			 "name", _("Ataxx"), 
+			 "version", VERSION,
+			 "copyright", "Copyright \xc2\xa9 1999-2003 Chris Rogers\n"
+				      "Copyright \xc2\xa9 2004-2005 Sjoerd Langkemper",
+			 "comments", _("A disk-flipping game where you attempt to dominate the board."),
+			 "authors", authors,
+			 "translator_credits", _("translator-credits"),
+			 NULL);
 }
 
 
@@ -422,31 +405,42 @@ static gboolean save_state_cb (GnomeClient * client, gint phase,
 			       GnomeInteractStyle interactive, gboolean fast,
 			       gpointer data)
 {
-  gchar * argv[] = { "gataxx", 
-    "--state=0000000000000000000000000000000000000000000000000" ,
-    "--turn=1"
-    };
+  gchar * argv[3];
+  gchar * state, * statestr;
   int i, j;
-gchar * state = argv[1] + 8;
+
+  argv[0] = "gataxx";  
+
+  state = statestr = g_malloc0 (BWIDTH * BHEIGHT + 1);
   
   for (j=0; j<BHEIGHT; j++) {
     for (i=0; i<BWIDTH; i++) {
       switch (gtk_gridboard_get_piece (gridboard, i, j)) {
-      case WHITE:
-	*state = '1';
-	break;
-      case BLACK:
-	*state = '2';
-	break;
+        case WHITE:
+  	  *state = '1';
+	  break;
+        case BLACK:
+	  *state = '2';
+	  break;
+        default:
+	  *state = '0';
       }
       state++;
     }
   }
 
-  if (turn == BLACK)
-    argv[2][7] = '2';
+  argv[1] = g_strconcat ("--state=", statestr, NULL);
 
-  gnome_client_set_restart_command (client, 2, argv);
+
+  if (turn == WHITE)
+	argv[2] = "--turn=1";
+  else
+	argv[2] = "--turn=2";
+
+  gnome_client_set_restart_command (client, 3, argv);
+  
+  g_free (statestr);
+  g_free (argv[1]);
 
   return TRUE;
 }
