@@ -22,6 +22,7 @@
 #include <config.h>
 #include <gnome.h>
 #include <stdlib.h>
+#include <math.h>
 
 #include "gbdefs.h"
 #include "gameconfig.h"
@@ -33,11 +34,12 @@
 #include "menu.h"
 #include "statusbar.h"
 #include "graphics.h"
+#include "cursors.h"
 
 /**********************************************************************/
 /* Exported Variables                                                 */
 /**********************************************************************/
-gint         game_state = STATE_NOT_PLAYING;
+gint         game_state = STATE_PLAYING;
 /**********************************************************************/
 
 
@@ -78,7 +80,6 @@ static void update_arena (void);
 static gint timeout_cb (void *data);
 static void destroy_game_timer (void);
 static void create_game_timer (void);
-static void create_demo_objects (void);
 static void move_all_robots (void);
 static void move_type2_robots (void);
 static void move_robots (void);
@@ -154,7 +155,15 @@ show_scores (guint pos)
   score_dialog = gnome_scores_display (nbuf, GAME_NAME, sbuf, pos);
   g_free (sbuf);
   g_free (nbuf);
+
+  if (!score_dialog)
+    return;
+
   gtk_window_set_transient_for (GTK_WINDOW (score_dialog), GTK_WINDOW (app));
+  gtk_dialog_set_has_separator (GTK_DIALOG (score_dialog), FALSE);
+  gtk_container_set_border_width (GTK_CONTAINER (score_dialog), 5);
+  gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (score_dialog)->vbox), 2);
+  gtk_window_set_resizable (GTK_WINDOW (score_dialog), FALSE);
   g_signal_connect (G_OBJECT (score_dialog), "destroy",
                     G_CALLBACK (gtk_widget_destroyed), &score_dialog);
 }
@@ -173,7 +182,7 @@ show_scores (guint pos)
 static guint
 log_score (gint sc)
 {
-  guint pos;
+  guint pos = 0;
   gchar *sbuf = NULL;
 
   if (properties_super_safe_moves ()) {
@@ -185,7 +194,8 @@ log_score (gint sc)
       sbuf = g_strdup_printf ("%s", game_config_filename (current_game_config ()));
     }
 
-  pos = gnome_score_log ((gfloat)sc, sbuf, TRUE);
+  if (sc != 0)
+    pos = gnome_score_log ((gfloat)sc, sbuf, TRUE);
   g_free (sbuf);
   update_score_state  ();
 
@@ -448,28 +458,29 @@ update_arena (void)
     }
   }
 
-  if (game_state != STATE_NOT_PLAYING) {
-    if (arena[player_xpos][player_ypos] != OBJECT_PLAYER) {
-      game_state = STATE_DEAD;
-      play_sound (SOUND_DIE);
-      arena[player_xpos][player_ypos] = OBJECT_PLAYER;
-      endlev_counter = 0;
-      add_aieee_bubble (player_xpos, player_ypos);
-      player_animation_dead ();
-    }
+  if (arena[player_xpos][player_ypos] != OBJECT_PLAYER) {
+    game_state = STATE_DEAD;
+    play_sound (SOUND_DIE);
+    arena[player_xpos][player_ypos] = OBJECT_PLAYER;
+    endlev_counter = 0;
+    add_aieee_bubble (player_xpos, player_ypos);
+    player_animation_dead ();
+    set_move_menu_sensitivity (FALSE);
+  }
 
-    if ((num_robots1 + num_robots2) <= 0) {
-      game_state = STATE_COMPLETE;
-      play_sound (SOUND_YAHOO);
-      endlev_counter = 0;
-      add_yahoo_bubble (player_xpos, player_ypos);
-      reset_player_animation ();
-    }
+  if ((num_robots1 + num_robots2) <= 0) {
+    game_state = STATE_COMPLETE;
+    play_sound (SOUND_YAHOO);
+    endlev_counter = 0;
+    add_yahoo_bubble (player_xpos, player_ypos);
+    reset_player_animation ();
+    set_move_menu_sensitivity (FALSE);
   }
 
   display_updated = FALSE;
 
   gnobots_statusbar_set (score, current_level+1, safe_teleports, num_robots1, num_robots2);
+  
 }
 
 
@@ -513,6 +524,7 @@ timeout_cb (void *data)
       clear_game_area ();
       generate_level ();
       game_state = STATE_PLAYING;
+      set_move_menu_sensitivity (TRUE);
       gnobots_statusbar_set (score, current_level+1, safe_teleports, num_robots1, num_robots2);
     }
   } else if (game_state == STATE_DEAD) {
@@ -525,12 +537,7 @@ timeout_cb (void *data)
 	  show_scores (sp);
 	}
       }
-      game_state = STATE_NOT_PLAYING;
-      remove_bubble ();
-      reset_player_animation ();
-      clear_game_area ();
-      create_demo_objects ();      
-      game_state = STATE_NOT_PLAYING;
+      start_new_game ();
     }
   }
 
@@ -571,34 +578,6 @@ create_game_timer (void)
 }
 
 
-/**
- * create_demo_objects
- *
- * Description:
- * Creates objects for the initial 'demo' screen
- **/
-static void
-create_demo_objects (void)
-{
-  clear_arena ();
-
-  arena[22][15] = OBJECT_PLAYER;
-
-  arena[22][9] = OBJECT_ROBOT1;
-  arena[22][21] = OBJECT_ROBOT1;
-
-  arena[28][15] = OBJECT_ROBOT2;
-  arena[16][15] = OBJECT_ROBOT2;
-
-  arena[28][9] = OBJECT_HEAP;
-  arena[28][21] = OBJECT_HEAP;
-  arena[16][9] = OBJECT_HEAP;
-  arena[16][21] = OBJECT_HEAP;
-
-  gnobots_statusbar_set (0, 0, 0, 0, 0);
-}
-
-
 /**
  * init_game
  *
@@ -608,27 +587,26 @@ create_demo_objects (void)
 void
 init_game (void)
 {
-  clear_game_area ();
-
-  create_demo_objects ();
-
   create_game_timer ();
 
   g_signal_connect (GTK_OBJECT (app), "key_press_event",
-                    GTK_SIGNAL_FUNC (keyboard_cb), 0);  
+                    GTK_SIGNAL_FUNC (keyboard_cb), 0);
+
+  start_new_game ();
 }
 
 
 /**
- * cleanup_game
+ * quit_game
  *
  * Description:
- * cleans up all of game resources
+ * Stop animation timeouts and exit.
  **/
 void
-cleanup_game (void)
+quit_game (void)
 {
   destroy_game_timer ();
+  gtk_main_quit();
 }
 
 
@@ -647,6 +625,9 @@ start_new_game (void)
   kills = 0;
   score_step = 0;
 
+  if (game_state == STATE_PLAYING)
+    log_score (score);
+
   conf = game_config ();
   g_return_if_fail  (conf != NULL);
 
@@ -666,6 +647,7 @@ start_new_game (void)
   game_state = STATE_PLAYING;
 
   gnobots_statusbar_set (score, current_level+1, safe_teleports, num_robots1, num_robots2);
+  set_move_menu_sensitivity (TRUE);
 }
 
 
@@ -1304,4 +1286,71 @@ game_keypress (gint key)
 
 }
 
+static void get_dir (int ix, int iy, int * odx, int * ody)
+{
+  int x, y, idx, idy;
+  double dx, dy, angle;
+  int octant;
+  const int movetable[8][2] = { {-1, 0}, {-1, -1}, {0, -1}, {1, -1},
+				{1, 0}, {1, 1}, {0, 1}, {-1, 1} };
+  x = CLAMP(ix/TILE_WIDTH, 0, GAME_WIDTH);
+  y = CLAMP(iy/TILE_HEIGHT, 0, GAME_HEIGHT);
+
+  /* If we click on our man then we assume we hold. */
+  if ((x == player_xpos) && (y == player_ypos)) {
+    *odx = 0;
+    *ody = 0;
+    return;
+  }
+
+  /* If the square clicked on is a valid move, go there. */
+  idx = x - player_xpos;
+  idy = y - player_ypos;
+  if ((ABS(idx) < 2) && (ABS(idy) < 2)) {
+    *odx = idx;
+    *ody = idy;
+    return;
+  }
+
+  /* Otherwise go in the general direction of the mouse click. */
+  dx = ix - (player_xpos + 0.5) * TILE_WIDTH;
+  dy = iy - (player_ypos + 0.5) * TILE_HEIGHT;
+
+  angle = atan2 (dy, dx);
+
+  /* Note the adjustment we have to make (+9, not +8) because atan2's idea 
+   * of octants and the ones we want are shifted by PI/8. */
+  octant = (((int)floor(8.0*angle/M_PI) + 9)/2) % 8; 
+
+  *odx = movetable[octant][0];
+  *ody = movetable[octant][1];
+}
+
+gboolean mouse_cb (GtkWidget * widget, GdkEventButton * e, gpointer data)
+{
+  int dx, dy;
+
+  if (game_state != STATE_PLAYING)
+    return TRUE;
+
+  get_dir (e->x, e->y, &dx, &dy);
+
+  player_move (dx, dy);
+
+  move_robots ();
+
+  return TRUE;
+}
+
+gboolean move_cb (GtkWidget *widget, GdkEventMotion *e, gpointer data)
+{
+  int dx, dy;
+
+  get_dir (e->x, e->y, &dx, &dy);
+
+  set_cursor_by_direction (widget->window, dx, dy);
+
+  return TRUE;
+}
+
 /**********************************************************************/
