@@ -25,6 +25,7 @@
 #include <gdk/gdkkeysyms.h>
 #include <gconf/gconf-client.h>
 #include <games-frame.h>
+#include <games-controls.h>
 
 #include "properties.h"
 #include "gameconfig.h"
@@ -44,6 +45,7 @@
 #define KB_TEXT_HEIGHT   32
 
 #define KEY_DIR              "/apps/gnobots2"
+#define KEY_SHOW_TOOLBAR     "/apps/gnobots2/preferences/show_toolbar"
 #define KEY_CONTROL_KEY      "/apps/gnobots2/preferences/key%02d"
 #define KEY_THEME            "/apps/gnobots2/preferences/theme"
 #define KEY_CONFIGURATION    "/apps/gnobots2/preferences/configuration"
@@ -66,6 +68,7 @@ struct _GnobotsProperties {
   gboolean super_safe_moves;
   gboolean sound;
   gboolean splats;
+  gboolean show_toolbar;
   GdkColor bgcolour;
   gint     selected_graphics;
   gint     selected_config;
@@ -86,23 +89,9 @@ enum {
   NCOLS
 }; /* Column indices for list */
 
-static GtkWidget         *etext[12];
-static GtkWidget         *key_labels[12];
 static GnobotsProperties  properties;
 
-static gint default_keys1[12] = {
-  GDK_Y, GDK_K, GDK_U, 
-  GDK_H, GDK_period, GDK_L,
-  GDK_B, GDK_J, GDK_N,
-  GDK_T, GDK_R, GDK_Return};
-
-static gint default_keys2[12] = {
-  GDK_Q, GDK_W, GDK_E, 
-  GDK_A, GDK_S, GDK_D,
-  GDK_Z, GDK_X, GDK_C,
-  GDK_T, GDK_R, GDK_Return};
-
-static gint default_keys3[12] = {
+static gint default_keys[12] = {
   GDK_KP_7, GDK_KP_8, GDK_KP_9, 
   GDK_KP_4, GDK_KP_5, GDK_KP_6,
   GDK_KP_1, GDK_KP_2, GDK_KP_3,
@@ -126,7 +115,6 @@ static void type_selection (GtkWidget*, gpointer);
 static void safe_cb (GtkWidget*, gpointer);
 static void sound_cb (GtkWidget*, gpointer);
 static void splat_cb (GtkWidget*, gpointer);
-static void keypad_cb (GtkWidget*, GdkEventKey*, gpointer);
 static void defkey_cb (GtkWidget*, gpointer);
 static void fill_typemenu (GtkWidget*);
 static void fill_pmapmenu (GtkWidget*);
@@ -514,6 +502,8 @@ type_selection (GtkWidget *widget, gpointer data)
   gconf_set_configuration (game_config_name (properties.selected_config));
 
   set_game_config (properties.selected_config);
+
+  start_new_game ();
 }
 
 
@@ -581,35 +571,6 @@ splat_cb (GtkWidget *widget, gpointer data)
 }
 
 
-/**
- * keypad_cb
- * @widget: widget
- * @event: event
- * @data: callback data
- *
- * Description:
- * handles message from the key selection widgets
- **/
-static void
-keypad_cb (GtkWidget *widget, GdkEventKey *event, gpointer data)
-{
-  gint keyval = event->keyval;
-  gint knum = GPOINTER_TO_INT(data);
-
-  keyval = keyboard_preferred (keyval);
-
-  properties.keys[knum] = keyval;
-
-  gtk_entry_set_text (GTK_ENTRY (widget), keyboard_string (keyval));
-  gtk_widget_set_sensitive (widget, FALSE);
-  gtk_widget_grab_focus (key_labels[knum]);
-  
-  gconf_set_control_key (knum, keyboard_string (keyval));
-  
-  keyboard_set (properties.keys);
-}
-
-
 /**
  * defkey_cb
  * @widget: widget
@@ -626,8 +587,6 @@ defkey_cb (GtkWidget *widget, gpointer data)
 
   for (i = 0; i < 12; ++i){
     properties.keys[i] = dkeys[i];
-    gtk_entry_set_text (GTK_ENTRY (etext[i]), 
-                        keyboard_string (properties.keys[i]));    
     gconf_set_control_key (i, keyboard_string (properties.keys[i]));
   }
   keyboard_set (properties.keys);
@@ -713,13 +672,6 @@ bg_color_callback (GtkWidget *widget, gpointer data)
   gconf_set_background_color (&properties.bgcolour);
 }
 
-static void
-enable_entry_cb (GtkWidget * widget, GtkWidget * target)
-{
-  gtk_widget_set_sensitive (target, TRUE);
-  gtk_widget_grab_focus (target);
-}
-
 /**
  * show_properties_dialog
  *
@@ -744,188 +696,175 @@ show_properties_dialog (void)
   GtkWidget *scrolled;
   GtkWidget *frame;
   GtkWidget *w;
+  GtkWidget *controls_list;
   GtkTooltips *tooltips;
   GtkListStore *list;
   GtkTreeViewColumn *column;
   GtkCellRenderer *renderer;
   GtkTreeSelection *selection;
-  gint keylayoutx[9] = { 0, 2, 4, 0, 2, 4, 0, 2, 4 };
-  gint keylayouty[9] = { 0, 0, 0, 1, 1, 1, 2, 2, 2 };
-  gchar * keylabels[9] = { "NW", "N", "NE", "W", "Hold",
-                            "E", "SW", "S", "SE"};
-  gint i;
-  
+
   if (propbox) 
     return;
 
   tooltips = gtk_tooltips_new ();
 
-  propbox = gtk_dialog_new_with_buttons (_("GNOME Robots Preferences"),
+  propbox = gtk_dialog_new_with_buttons (_("Robots Preferences"),
                                          GTK_WINDOW  (app),
                                          GTK_DIALOG_DESTROY_WITH_PARENT,
                                          GTK_STOCK_CLOSE, GTK_RESPONSE_ACCEPT,
                                          NULL);
+  gtk_dialog_set_has_separator (GTK_DIALOG (propbox), FALSE);
+  gtk_container_set_border_width (GTK_CONTAINER (propbox), 5);
+  gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (propbox)->vbox), 2);
   /* Set up notebook and add it to hbox of the gtk_dialog */
   g_signal_connect (G_OBJECT (propbox), "destroy",
                     G_CALLBACK (gtk_widget_destroyed), &propbox);
   
   notebook = gtk_notebook_new ();
+  gtk_container_set_border_width (GTK_CONTAINER (notebook), 5);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (propbox)->vbox), notebook, 
                       TRUE, TRUE, 0);
 
   /* The configuration page */
-  cpage = gtk_vbox_new (FALSE, 0);
-  gtk_container_set_border_width (GTK_CONTAINER (cpage), GNOME_PAD_SMALL);
+  cpage = gtk_vbox_new (FALSE, 18);
+  gtk_container_set_border_width (GTK_CONTAINER (cpage), 12);
 
   frame = games_frame_new (_("Game Type"));
-  gtk_box_pack_start (GTK_BOX (cpage), frame, TRUE, TRUE, GNOME_PAD);
+  gtk_box_pack_start (GTK_BOX (cpage), frame, TRUE, TRUE, 0);
 
-  vbox = gtk_vbox_new (FALSE, 0);
+  vbox = gtk_vbox_new (FALSE, 6);
   gtk_container_add (GTK_CONTAINER (frame), vbox);
 
-  hbox = gtk_hbox_new (TRUE, GNOME_PAD);
-  gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, GNOME_PAD);
+  hbox = gtk_hbox_new (TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
-  if (game_state == STATE_NOT_PLAYING) {
-    typemenu = gtk_combo_box_new_text ();
-    g_signal_connect (G_OBJECT (typemenu), "changed",
-                      G_CALLBACK (type_selection), NULL);
-    fill_typemenu (typemenu);
-    gtk_box_pack_start_defaults (GTK_BOX (hbox), typemenu);
-
-    list = gtk_list_store_new (NCOLS,
-                               G_TYPE_STRING, /* Property */ 
-                               G_TYPE_STRING, /* Value */
-                               G_TYPE_INT); /* Index - remains hidden */
-    /* Create view */
-    list_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (list));
-    g_object_unref (list); /* Do I need to create a list store? */
-
-    renderer = gtk_cell_renderer_text_new ();
-    column = gtk_tree_view_column_new_with_attributes (_("Property"), 
-                                                       renderer, 
-                                                       "text", PROPERTY_STRING, 
-                                                       NULL);
-    gtk_tree_view_append_column (GTK_TREE_VIEW (list_view), column);
+  typemenu = gtk_combo_box_new_text ();
+  g_signal_connect (G_OBJECT (typemenu), "changed",
+		    G_CALLBACK (type_selection), NULL);
+  fill_typemenu (typemenu);
+  gtk_box_pack_start_defaults (GTK_BOX (hbox), typemenu);
+  
+  list = gtk_list_store_new (NCOLS,
+			     G_TYPE_STRING, /* Property */ 
+			     G_TYPE_STRING, /* Value */
+			     G_TYPE_INT); /* Index - remains hidden */
+  /* Create view */
+  list_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (list));
+  
+  renderer = gtk_cell_renderer_text_new ();
+  column = gtk_tree_view_column_new_with_attributes (_("Property"), 
+						     renderer, 
+						     "text", PROPERTY_STRING, 
+						     NULL);
+  gtk_tree_view_append_column (GTK_TREE_VIEW (list_view), column);
     
-    renderer = gtk_cell_renderer_text_new ();
-    column = gtk_tree_view_column_new_with_attributes (_("Value"), 
-                                                       renderer, 
-                                                       "text", VALUE_STRING, 
-                                                       NULL);
-    gtk_tree_view_append_column (GTK_TREE_VIEW (list_view), column);
+  renderer = gtk_cell_renderer_text_new ();
+  column = gtk_tree_view_column_new_with_attributes (_("Value"), 
+						     renderer, 
+						     "text", VALUE_STRING, 
+						     NULL);
+  gtk_tree_view_append_column (GTK_TREE_VIEW (list_view), column);
 
-    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (list_view));
-    gtk_tree_selection_set_mode  (selection, GTK_SELECTION_SINGLE);
+  selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (list_view));
+  gtk_tree_selection_set_mode  (selection, GTK_SELECTION_SINGLE);
 
-#if 0
-    gtk_clist_set_column_width (GTK_CLIST (clist), 0, 400);
-    gtk_clist_set_column_width (GTK_CLIST (clist), 1, 50);
-    gtk_clist_column_titles_passive (GTK_CLIST (clist));
-    gtk_clist_column_titles_show (GTK_CLIST (clist));
-#endif
+  fill_property_list ();
 
-    fill_property_list ();
+  scrolled = gtk_scrolled_window_new (NULL, NULL);
+  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled),
+				  GTK_POLICY_AUTOMATIC,
+				  GTK_POLICY_AUTOMATIC);
+  gtk_scrolled_window_set_shadow_type 
+    (GTK_SCROLLED_WINDOW (scrolled), GTK_SHADOW_IN);
+  gtk_widget_set_size_request (scrolled, 400, 200);
+  gtk_container_add (GTK_CONTAINER (scrolled), list_view);
 
-    /*gtk_widget_set_size_request (list_view, 300, 200);*/
+  gtk_box_pack_start (GTK_BOX (vbox), scrolled, TRUE, TRUE, 0);
 
-    scrolled = gtk_scrolled_window_new (NULL, NULL);
-    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled),
-                                    GTK_POLICY_AUTOMATIC,
-                                    GTK_POLICY_AUTOMATIC);
-    gtk_scrolled_window_set_shadow_type 
-      (GTK_SCROLLED_WINDOW (scrolled), GTK_SHADOW_IN);
-    gtk_widget_set_size_request (scrolled, 400, 200);
-    gtk_container_add (GTK_CONTAINER (scrolled), list_view);
+  frame = games_frame_new (_("Options"));
+  gtk_box_pack_start (GTK_BOX (cpage), frame, FALSE, FALSE, 0);
+  vbox = gtk_vbox_new (TRUE, 6);
+  gtk_container_add (GTK_CONTAINER (frame), vbox);
 
-    gtk_box_pack_start (GTK_BOX (vbox), scrolled, TRUE, TRUE, GNOME_PAD_SMALL);
+  table = gtk_table_new (2, 2, FALSE);
+  gtk_table_set_row_spacings (GTK_TABLE (table), 6);
+  gtk_table_set_col_spacings (GTK_TABLE (table), 12);
+  gtk_box_pack_start (GTK_BOX (vbox), table, FALSE, FALSE, 0);
 
-    frame = games_frame_new (_("Options"));
-    gtk_box_pack_start (GTK_BOX (cpage), frame, TRUE, TRUE, GNOME_PAD);
-    vbox = gtk_vbox_new (TRUE, 6);
-    gtk_container_add (GTK_CONTAINER (frame), vbox);
+  chkbox = gtk_check_button_new_with_mnemonic (_("_Use safe moves"));
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (chkbox), 
+				properties.safe_moves);
+  g_signal_connect (G_OBJECT (chkbox), "clicked",
+		    (GtkSignalFunc)safe_cb, NULL);
+  gtk_table_attach (GTK_TABLE (table), chkbox, 0, 1, 0, 1, GTK_FILL, 0, 0, 0);
+  gtk_tooltips_set_tip (tooltips, chkbox,
+			_("Prevent some dangerous moves"), 
+			_("Prevent accidental moves that result in getting killed."));
 
-    table = gtk_table_new (2, 2, TRUE);
-    gtk_table_set_row_spacings (GTK_TABLE (table), 6);
-    gtk_table_set_col_spacings (GTK_TABLE (table), 6);
-    gtk_box_pack_start (GTK_BOX (vbox), table, FALSE, TRUE, GNOME_PAD);
+  chkbox = gtk_check_button_new_with_mnemonic (_("U_se super safe moves"));
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (chkbox), properties.super_safe_moves);
+  g_signal_connect (G_OBJECT (chkbox), "clicked",
+		    (GtkSignalFunc)super_safe_cb, NULL);
+  gtk_table_attach (GTK_TABLE (table), chkbox, 0, 1, 1, 2, GTK_FILL, 0, 0, 0);
+  gtk_tooltips_set_tip (tooltips, chkbox,
+			_("Prevent all dangerous moves"), 
+			_("Prevents all moves that result in getting killed."));
 
-    chkbox = gtk_check_button_new_with_label (_("Use safe moves"));
-    GTK_TOGGLE_BUTTON (chkbox)->active = properties.safe_moves;
-    g_signal_connect (G_OBJECT (chkbox), "clicked",
-                      (GtkSignalFunc)safe_cb, NULL);
-    gtk_table_attach_defaults (GTK_TABLE (table), chkbox, 0, 1, 0, 1);
-    gtk_tooltips_set_tip (tooltips, chkbox,
-			  _("Prevent some dangerous moves"), 
-			  _("Prevent accidental moves that result in getting killed."));
+  chkbox = gtk_check_button_new_with_mnemonic (_("_Enable sounds"));
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (chkbox), properties.sound);
+  g_signal_connect (G_OBJECT (chkbox), "clicked",
+		    (GtkSignalFunc)sound_cb, NULL);
+  gtk_table_attach (GTK_TABLE (table), chkbox, 1, 2, 0, 1, GTK_FILL, 0, 0, 0);
+  gtk_tooltips_set_tip (tooltips, chkbox,
+			_("Play sounds for major events"), 
+			_("Play sounds for events like winning a level and dying."));
 
-    chkbox = gtk_check_button_new_with_label (_("Use super safe moves"));
-    GTK_TOGGLE_BUTTON (chkbox)->active = properties.super_safe_moves;
-    g_signal_connect (G_OBJECT (chkbox), "clicked",
-                      (GtkSignalFunc)super_safe_cb, NULL);
-    gtk_table_attach_defaults (GTK_TABLE (table), chkbox, 0, 1, 1, 2);
-    gtk_tooltips_set_tip (tooltips, chkbox,
-			  _("Prevent all dangerous moves"), 
-			  _("Prevents all moves that result in getting killed."));
+  chkbox = gtk_check_button_new_with_mnemonic (_("E_nable splats"));
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (chkbox), properties.splats);
+  g_signal_connect (G_OBJECT (chkbox), "clicked",
+		    (GtkSignalFunc)splat_cb, NULL);
+  gtk_table_attach (GTK_TABLE (table), chkbox, 1, 2, 1, 2, GTK_FILL, 0, 0, 0);
+  gtk_tooltips_set_tip (tooltips, chkbox,
+			_("Play a sound when two robots collide"), 
+			_("Play the most common, and potentially the most annoying, sound."));
 
-    chkbox = gtk_check_button_new_with_label (_("Enable sounds"));
-    GTK_TOGGLE_BUTTON (chkbox)->active = properties.sound;
-    g_signal_connect (G_OBJECT (chkbox), "clicked",
-                      (GtkSignalFunc)sound_cb, NULL);
-    gtk_table_attach_defaults (GTK_TABLE (table), chkbox, 1, 2, 0, 1);
-    gtk_tooltips_set_tip (tooltips, chkbox,
-			  _("Play sounds for major events"), 
-			  _("Play sounds for events like winning a level and dying."));
-
-    chkbox = gtk_check_button_new_with_label (_("Enable splats"));
-    GTK_TOGGLE_BUTTON (chkbox)->active = properties.splats;
-    g_signal_connect (G_OBJECT (chkbox), "clicked",
-                      (GtkSignalFunc)splat_cb, NULL);
-    gtk_table_attach_defaults (GTK_TABLE (table), chkbox, 1, 2, 1, 2);
-    gtk_tooltips_set_tip (tooltips, chkbox,
-			  _("Play a sound when two robots collide"), 
-			  _("Play the most common, and potentially the most annoying, sound."));
-
-  } else {
-    label = gtk_label_new (_("You Cannot Change the Game Type When Playing"));
-    gtk_box_pack_start_defaults (GTK_BOX (hbox), label);
-
-  }
   label = gtk_label_new_with_mnemonic (_("Game"));
   gtk_notebook_append_page (GTK_NOTEBOOK (notebook), cpage, label);
 
 
   /* The graphics page */
-  gpage = gtk_vbox_new (FALSE, GNOME_PAD);
-  gtk_container_set_border_width (GTK_CONTAINER (gpage), GNOME_PAD_SMALL);
+  gpage = gtk_vbox_new (FALSE, 18);
+  gtk_container_set_border_width (GTK_CONTAINER (gpage), 12);
 
   frame = games_frame_new (_("Graphics Theme"));
-  gtk_box_pack_start (GTK_BOX (gpage), frame, FALSE, FALSE, GNOME_PAD);
+  gtk_box_pack_start (GTK_BOX (gpage), frame, FALSE, FALSE, 0);
 
   table = gtk_table_new (2, 2, FALSE);
-  gtk_container_set_border_width (GTK_CONTAINER (table), 0);
   gtk_table_set_row_spacings (GTK_TABLE (table), 6);
-  gtk_table_set_col_spacings (GTK_TABLE (table), 6);
+  gtk_table_set_col_spacings (GTK_TABLE (table), 12);
   gtk_container_add (GTK_CONTAINER (frame), table);
 
-  label = gtk_label_new (_("Image theme:"));
+  label = gtk_label_new_with_mnemonic (_("_Image theme:"));
   gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
-  gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 0, 1);
+  gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1, GTK_FILL, 0, 0, 0);
 
   pmapmenu = gtk_combo_box_new_text ();
   g_signal_connect (G_OBJECT (pmapmenu), "changed",
                     G_CALLBACK (pmap_selection), NULL);
+  gtk_label_set_mnemonic_widget (GTK_LABEL (label), pmapmenu);
+
   fill_pmapmenu (pmapmenu);
   gtk_table_attach_defaults (GTK_TABLE (table), pmapmenu, 1, 2, 0, 1);
 
-  label = gtk_label_new (_("Background color:"));
+  label = gtk_label_new_with_mnemonic (_("_Background color:"));
   gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
-  gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 1, 2);
+  gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2, GTK_FILL, 0, 0, 0);
 
   w  = gtk_color_button_new ();
   gtk_color_button_set_color (GTK_COLOR_BUTTON (w), &properties.bgcolour);
   g_signal_connect (G_OBJECT (w), "color_set",
                     G_CALLBACK (bg_color_callback), NULL);
+  gtk_label_set_mnemonic_widget (GTK_LABEL (label), w);
 
   gtk_table_attach_defaults (GTK_TABLE (table), w, 1, 2, 1, 2);
 
@@ -933,104 +872,40 @@ show_properties_dialog (void)
   gtk_notebook_append_page (GTK_NOTEBOOK (notebook), gpage, label);
 
   /* The keyboard page */
-  kpage = gtk_vbox_new (FALSE, GNOME_PAD);
-  gtk_container_set_border_width (GTK_CONTAINER (kpage), GNOME_PAD_SMALL);
+  kpage = gtk_vbox_new (FALSE, 18);
+  gtk_container_set_border_width (GTK_CONTAINER (kpage), 12);
 
   frame = games_frame_new (_("Keyboard Controls"));
-  gtk_box_pack_start (GTK_BOX (kpage), frame, FALSE, FALSE, GNOME_PAD);
+  gtk_box_pack_start (GTK_BOX (kpage), frame, TRUE, TRUE, 0);
   vbox = gtk_vbox_new (FALSE, 6);
   gtk_container_add (GTK_CONTAINER (frame), vbox);
 
-  hbox = gtk_hbox_new (FALSE, GNOME_PAD);
-  gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, GNOME_PAD);
+  controls_list = games_controls_list_new ();
+  games_controls_list_add_controls (GAMES_CONTROLS_LIST (controls_list), 
+				    "/apps/gnobots2/preferences/key00",
+				    "/apps/gnobots2/preferences/key01",
+				    "/apps/gnobots2/preferences/key02",
+				    "/apps/gnobots2/preferences/key03",
+				    "/apps/gnobots2/preferences/key05",
+				    "/apps/gnobots2/preferences/key06",
+				    "/apps/gnobots2/preferences/key07",
+				    "/apps/gnobots2/preferences/key08",
+				    "/apps/gnobots2/preferences/key04",
+				    "/apps/gnobots2/preferences/key09",
+				    "/apps/gnobots2/preferences/key10",
+				    "/apps/gnobots2/preferences/key11",
+				    NULL);
 
-  table = gtk_table_new (8, 3, TRUE);
+  gtk_box_pack_start (GTK_BOX (vbox), controls_list, TRUE, TRUE, 0);
 
-  for (i = 0; i<9; i++) {
-    key_labels[i] = gtk_button_new_with_label (keylabels[i]);
-    gtk_table_attach (GTK_TABLE (table), key_labels[i], keylayoutx[i],
-                      keylayoutx[i]+1, keylayouty[i], keylayouty[i]+1,
-                      GTK_FILL, GTK_FILL, 3, 3);
-    etext[i] = gtk_entry_new ();
-    gtk_entry_set_text (GTK_ENTRY (etext[i]),
-                        keyboard_string (properties.keys[i]));
-    gtk_editable_set_editable (GTK_EDITABLE (etext[i]), FALSE);
-    gtk_widget_set_sensitive (etext[i], FALSE);
-    gtk_widget_set_size_request (etext[i], KB_TEXT_WIDTH, KB_TEXT_HEIGHT);
-    gtk_table_attach (GTK_TABLE (table), etext[i],
-                      keylayoutx[i]+1 , keylayoutx[i]+2, keylayouty[i],
-                      keylayouty[i]+1, GTK_FILL, GTK_FILL, 3, 3);
-    g_signal_connect (G_OBJECT (etext[i]), "key_press_event",
-                      G_CALLBACK (keypad_cb), GINT_TO_POINTER(i));
-    g_signal_connect (G_OBJECT (key_labels[i]), "clicked",
-                      G_CALLBACK (enable_entry_cb), etext[i]);
-  }
-  
-  gtk_box_pack_start (GTK_BOX (hbox), table, TRUE, TRUE, GNOME_PAD);
+  hbox = gtk_hbutton_box_new ();
+  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbox), GTK_BUTTONBOX_START);
+  gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
-  table = gtk_table_new (2, 3, FALSE);
-
-  key_labels[9] = gtk_button_new_with_label (_("Teleport"));
-  gtk_table_attach (GTK_TABLE (table), key_labels[9], 0, 1, 0, 1, GTK_FILL, GTK_FILL, 3, 3);
-  etext[9] = gtk_entry_new ();
-  gtk_entry_set_text (GTK_ENTRY (etext[9]),
-                      keyboard_string (properties.keys[9]));
-  gtk_widget_set_sensitive (etext[9], FALSE);
-  gtk_editable_set_editable (GTK_EDITABLE (etext[9]), FALSE);
-  gtk_widget_set_size_request (etext[9], KB_TEXT_WIDTH, KB_TEXT_HEIGHT);
-  gtk_table_attach (GTK_TABLE (table), etext[9], 1, 2, 0, 1, GTK_FILL, GTK_FILL, 3, 3);
-  g_signal_connect (G_OBJECT (etext[9]), "key_press_event",
-                    G_CALLBACK (keypad_cb), (gpointer)9);
-  g_signal_connect (G_OBJECT (key_labels[9]), "clicked",
-                    G_CALLBACK (enable_entry_cb), etext[9]);
-  
-  key_labels[10] = gtk_button_new_with_label (_("Random Teleport"));
-  gtk_table_attach (GTK_TABLE (table), key_labels[10], 0, 1, 1, 2, GTK_FILL, GTK_FILL, 3, 3);
-  etext[10] = gtk_entry_new ();
-  gtk_entry_set_text (GTK_ENTRY (etext[10]),
-                      keyboard_string (properties.keys[10]));
-  gtk_editable_set_editable (GTK_EDITABLE (etext[10]), FALSE);
-  gtk_widget_set_sensitive (etext[10], FALSE);
-  gtk_widget_set_size_request (etext[10], KB_TEXT_WIDTH, KB_TEXT_HEIGHT);
-  gtk_table_attach (GTK_TABLE (table), etext[10], 1, 2, 1, 2, GTK_FILL, GTK_FILL, 3, 3);
-  g_signal_connect (G_OBJECT (etext[10]), "key_press_event",
-                    G_CALLBACK (keypad_cb), (gpointer)10);
-  g_signal_connect (G_OBJECT (key_labels[10]), "clicked",
-                    G_CALLBACK (enable_entry_cb), etext[10]);
-
-  key_labels[11] = gtk_button_new_with_label (_("Wait"));
-  gtk_table_attach (GTK_TABLE (table), key_labels[11], 0, 1, 2, 3, GTK_FILL, GTK_FILL, 3, 3);
-  etext[11] = gtk_entry_new ();
-  gtk_entry_set_text (GTK_ENTRY (etext[11]),
-                      keyboard_string (properties.keys[11]));
-  gtk_widget_set_sensitive (etext[11], FALSE);
-  gtk_editable_set_editable (GTK_EDITABLE (etext[11]), FALSE);
-  gtk_widget_set_size_request (etext[11], KB_TEXT_WIDTH, KB_TEXT_HEIGHT);
-  gtk_table_attach (GTK_TABLE (table), etext[11], 1, 2, 2, 3, GTK_FILL, GTK_FILL, 3, 3);
-  g_signal_connect (G_OBJECT (etext[11]), "key_press_event",
-                    G_CALLBACK (keypad_cb), (gpointer)11);
-  g_signal_connect (G_OBJECT (key_labels[11]), "clicked",
-                    G_CALLBACK (enable_entry_cb), etext[11]);
-
-  gtk_box_pack_start (GTK_BOX (hbox), table, TRUE, TRUE, GNOME_PAD);
-
-  hbox = gtk_hbox_new (TRUE, GNOME_PAD);
-  gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, GNOME_PAD);
-
-  dbut = gtk_button_new_with_label (_("Use the Keypad"));
+  dbut = gtk_button_new_with_mnemonic (_("_Restore Defaults"));
   g_signal_connect (G_OBJECT (dbut), "clicked",
-                    G_CALLBACK (defkey_cb), (gpointer)default_keys3);  
-  gtk_box_pack_start (GTK_BOX (hbox), dbut, FALSE, TRUE, GNOME_PAD);
-
-  dbut = gtk_button_new_with_label (_("Use Left Hand Keys"));
-  g_signal_connect (G_OBJECT (dbut), "clicked",
-                    G_CALLBACK (defkey_cb), (gpointer)default_keys2);  
-  gtk_box_pack_start (GTK_BOX (hbox), dbut, FALSE, TRUE, GNOME_PAD);
-
-  dbut = gtk_button_new_with_label (_("Use Original Robots Keys"));
-  g_signal_connect (G_OBJECT (dbut), "clicked",
-                    G_CALLBACK (defkey_cb), (gpointer)default_keys1);  
-  gtk_box_pack_start (GTK_BOX (hbox), dbut, FALSE, TRUE, GNOME_PAD);
+                    G_CALLBACK (defkey_cb), (gpointer)default_keys);  
+  gtk_box_pack_start (GTK_BOX (hbox), dbut, FALSE, FALSE, 0);
 
   label = gtk_label_new_with_mnemonic (_("Keyboard"));
   gtk_notebook_append_page (GTK_NOTEBOOK (notebook), kpage, label);
@@ -1082,7 +957,7 @@ load_properties (void)
   gchar * bgcolour;
 
   for (i = 0; i < 12; i++) {
-    properties.keys[i] = default_keys1[i];
+    properties.keys[i] = default_keys[i];
 
     sprintf (buffer, KEY_CONTROL_KEY, i);
 
@@ -1091,7 +966,7 @@ load_properties (void)
       properties.keys[i] = gdk_keyval_from_name (str);
     }
     if ((str == NULL) || (properties.keys[i] == GDK_VoidSymbol)) {
-      properties.keys[i] = default_keys3[i];
+      properties.keys[i] = default_keys[i];
     }
     g_free (str);
   }
@@ -1138,6 +1013,8 @@ load_properties (void)
                                             KEY_ENABLE_SOUND, NULL);
   properties.splats = gconf_client_get_bool (get_gconf_client (),
                                              KEY_ENABLE_SPLATS, NULL);
+  properties.show_toolbar = gconf_client_get_bool (get_gconf_client (),
+						   KEY_SHOW_TOOLBAR, NULL);
 
   set_game_graphics (properties.selected_graphics);
   set_game_config (properties.selected_config);
@@ -1201,6 +1078,13 @@ gconf_set_enable_splats (gboolean value)
                          value, NULL);
 }
 
+void
+gconf_set_show_toolbar (gboolean value)
+{
+  gconf_client_set_bool (get_gconf_client (), KEY_SHOW_TOOLBAR,
+			 value, NULL);
+}
+
 void
 gconf_set_control_key (gint i, gchar *value)
 {
@@ -1303,6 +1187,23 @@ properties_splats (void)
   return properties.splats;
 }
 
+
+/**
+ * properties_show_toolbar
+ *
+ * Description:
+ * returns toolbar setting
+ *
+ * Returns:
+ * TRUE if splats are selected
+ **/
+gboolean
+properties_show_toolbar (void)
+{
+  return properties.show_toolbar;
+}
+
+
 /**
  * properties_set_config
  * @n: config number
