@@ -61,14 +61,6 @@ extern guint start_cave;
 extern guint32  joystick_deviceid;
 extern gfloat   joystick_switch_level;
 
-
-/* Which scroll method should we use */
-
-
-extern void (*view_scroll_method) (GStonesView *view, GStonesCave *cave);
-
-
-
 /* The game can be in different states.  These state decides, how to
    react if some events occur.  */
 
@@ -113,7 +105,6 @@ preferences_save_global (void);
 void 
 preferences_save (gboolean global);
 
-void gconf_set_scroll_method (gchar *value);
 void gconf_set_game_name (gchar *value);
 void gconf_set_start_cave (gint value);
 void gconf_set_sound_enabled (gboolean value);
