@@ -32,10 +32,19 @@ guint idle_id = 0;
 /* A flag for whether we have valid pixmap data. */
 gboolean pixmaps_ready = FALSE;
 
-/* FIXME: How do we initialise these to NULL ? */
 GdkPixmap *pixmaps[MAX_COLOURS][NFRAMES];
 GdkPixmap *blank_pixmap = NULL;
 
+/* These are allocated on an as-needed basis, but never disposed of. */
+GdkGC *gridgc = NULL;
+GdkGC *bggc = NULL;
+GdkGC *cursorgc = NULL;
+
+/* FIXME: These should not be hard-coded. */
+GdkColor gridcolor =   { 0, 0x5050, 0x5050, 0x5050 };
+GdkColor bgcolor =     { 0, 0x1010, 0x1010, 0x1010 };
+GdkColor cursorcolor = { 0, 0xffff, 0xb7b7, 0x4646 };
+
 /* FIXME: Can we make this not global ? (redraw is the problem) */
 GtkWidget *canvaswidget;
 
@@ -45,6 +54,8 @@ gint cursor_x = -1;
 gint cursor_y = -1;
 gboolean draw_cursor = FALSE;
 
+gboolean fast_animation = FALSE;
+
 void pixels_to_logical (gint px, gint py, gint *lx, gint *ly)
 {
 	*lx = px / tile_size;
@@ -84,11 +95,20 @@ static void draw_ball_with_offset (GtkWidget * canvas, game_cell *p, int x,
 											 y*tile_size - dy, tile_size, tile_size);	
 	}
 
+	/* Draw the cursor is needed. */
 	if (draw_cursor && (x == cursor_x) && (y == cursor_y)) {
-		/* FIXME: This needs a better gc (and a colour to match the grid). */
-		gdk_draw_rectangle (canvaswidget->window, canvaswidget->style->white_gc,
-												FALSE, x*tile_size + 1, y*tile_size + 1, 
-												tile_size - 2, tile_size - 2);
+		if (cursorgc == NULL) {
+			cursorgc = gdk_gc_new (canvaswidget->window);
+			gdk_colormap_alloc_color (gdk_colormap_get_system (), 
+																&cursorcolor, TRUE, TRUE);
+			gdk_gc_set_foreground (cursorgc, &cursorcolor);
+			gdk_gc_set_line_attributes (cursorgc, 2, GDK_LINE_SOLID,
+																	GDK_CAP_BUTT, GDK_JOIN_MITER);
+		}
+
+		gdk_draw_rectangle (canvaswidget->window, cursorgc,
+												FALSE, x*tile_size + 2, y*tile_size + 2, 
+												tile_size - 3, tile_size - 3);
 	}
 
 }
@@ -98,6 +118,13 @@ static void draw_ball (GtkWidget * canvas, game_cell *p, int x, int y)
 	draw_ball_with_offset (canvas, p, x, y, 0, 0);
 }
 
+void fast_animation_enable (gboolean state)
+{
+	fast_animation = state;
+	
+	gconf_client_set_bool (gcclient, GCONF_FAST_ANIMATION_KEY, state, NULL);
+}
+
 void cursor_erase (void)
 {
 	draw_cursor = FALSE;
@@ -118,6 +145,18 @@ gboolean expose_cb (GtkWidget *canvas, GdkEventExpose *event, gpointer data)
 	int x, y;
 	game_cell *p;
 
+	if (gridgc == NULL) {
+		gridgc = gdk_gc_new (canvas->window);
+		gdk_colormap_alloc_color (gdk_colormap_get_system (), 
+															&gridcolor, TRUE, TRUE);
+		gdk_gc_set_foreground (gridgc, &gridcolor);
+		
+		bggc = gdk_gc_new (canvas->window);
+		gdk_colormap_alloc_color (gdk_colormap_get_system (), 
+															&bgcolor, TRUE, TRUE);
+		gdk_gc_set_foreground (bggc, &bgcolor);
+	}
+
 	/* We consider two cases. One is here we have resized and the pixmaps
 	 * aren't ready yet, in that case (the else block) we just draw the
 	 * grid. Otherwise we draw everything using the tiles. */
@@ -134,24 +173,21 @@ gboolean expose_cb (GtkWidget *canvas, GdkEventExpose *event, gpointer data)
 
 		/* Fixup the left and bottom lines. */
 		if ((event->area.y + event->area.height + 1) >= board_height*tile_size) {
-			/* FIXME: This should have it's own gc. */
-			gdk_draw_line (canvas->window, canvas->style->white_gc,
-										 event->area.x, board_height*tile_size - 1, 
+			gdk_draw_line (canvas->window, gridgc,
+										 event->area.x, board_height*tile_size, 
 										 event->area.x + event->area.width - 2, 
-										 board_height*tile_size - 1);
+										 board_height*tile_size);
 		}
 		if ((event->area.x + event->area.width + 1) >= board_width*tile_size) {
-			/* FIXME: This should have it's own gc. */
-			gdk_draw_line (canvas->window, canvas->style->white_gc,
-										 board_width*tile_size - 1, event->area.y,
-										 board_width*tile_size - 1, 
+			gdk_draw_line (canvas->window, gridgc,
+										 board_width*tile_size, event->area.y,
+										 board_width*tile_size, 
 										 event->area.y + event->area.height - 2);
 		}
 
 	} else { /* Draw only the grid. */
 
-		/* FIXME: This should be a background colour. */
-		gdk_draw_rectangle (canvas->window, canvas->style->black_gc, TRUE,
+		gdk_draw_rectangle (canvas->window, bggc, TRUE,
 												event->area.x, event->area.y, 
 												event->area.width, event->area.height);
 
@@ -159,8 +195,7 @@ gboolean expose_cb (GtkWidget *canvas, GdkEventExpose *event, gpointer data)
 		for (x = tile_size*(event->area.x/tile_size);
 				 x <= tile_size*((event->area.x + event->area.width)/tile_size);
 				 x += tile_size) {
-			/* FIXME: This should have it's own gc. */
-			gdk_draw_line (canvas->window, canvas->style->white_gc, x,
+			gdk_draw_line (canvas->window, gridgc, x,
 										 event->area.y, x, event->area.y + event->area.height);
 		}
 
@@ -168,8 +203,7 @@ gboolean expose_cb (GtkWidget *canvas, GdkEventExpose *event, gpointer data)
 		for (x = tile_size*(event->area.y/tile_size);
 				 x <= tile_size*((event->area.y + event->area.height)/tile_size);
 				 x += tile_size) {
-			/* FIXME: This should have it's own gc. */
-			gdk_draw_line (canvas->window, canvas->style->white_gc,
+			gdk_draw_line (canvas->window, gridgc,
 										 event->area.x, x, event->area.x + event->area.width, x);
 		}
 
@@ -220,6 +254,8 @@ static gboolean render_cb (GtkWidget *canvas)
 	gchar *suffix;
 	gint length;
 	GtkWidget *dialog;
+	static guchar r, g, b, br, bg, bb;
+	guchar tr, tg, tb;
 
 	if (idle_state == INIT) {
 		last_tile_size = tile_size;
@@ -233,26 +269,31 @@ static gboolean render_cb (GtkWidget *canvas)
 			g_object_unref (bg_pixbuf);
 
 		/* Draw up the background with the top and left grid lines. */
-		/* FIXME: hard-coded colours. */
 		bg_pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, tile_size,
 																tile_size);
 		/* FIXME: This is too large for this function, ship off else-where. */
 		p = gdk_pixbuf_get_pixels (bg_pixbuf);
 		l = gdk_pixbuf_get_rowstride (bg_pixbuf);
+		r = gridcolor.red >> 8;
+		g = gridcolor.green >> 8;
+		b = gridcolor.blue >> 8;
+		br = bgcolor.red >> 8;
+		bg = bgcolor.green >> 8;
+		bb = bgcolor.blue >> 8;
 		for (i=0; i<tile_size; i++) {
-			*p++ = 0xff;
-			*p++ = 0xff;
-			*p++ = 0xff;
+			*p++ = r;
+			*p++ = g;
+			*p++ = b;
 		}
 		for (j=1; j<tile_size; j++) {
 					p = p + l - 3*tile_size;
-					*p++ = 0xff;
-					*p++ = 0xff;
-					*p++ = 0xff;
+					*p++ = r;
+					*p++ = g;
+					*p++ = b;
 					for (i=1; i<tile_size; i++) {
-						*p++ = 0x00;
-						*p++ = 0x00;
-						*p++ = 0x00;
+						*p++ = br;
+						*p++ = bg;
+						*p++ = bb;
 					}
 		}
 		if (blank_pixmap != NULL)
@@ -369,21 +410,20 @@ static gboolean render_cb (GtkWidget *canvas)
 			/* Instead we have a fade-out. */
 			/* This method does avoid the "phase" problem of destroying
 			 * a spinning object at an arbitrary phase. */
-			/* FIXME: Should this be the border colour fading to the
-			 * background colour rather than the current hard-coded stuff ? */
+			/* FIXME: This fade from white scheme only works for dark backgrounds. */
 			bp = gdk_pixbuf_get_pixels (tile);
 			l = gdk_pixbuf_get_rowstride (tile);
 			/* Note that this avoids the border. */
 			shift = (m - DESTFRAMESOFS)/2;
+			tr = br + ((0xff - br) >> shift);
+			tg = bg + ((0xff - bg) >> shift);
+			tb = bb + ((0xff - bb) >> shift);
 			for (j=1; j<tile_size; j++) {
 				p = bp + j*l + 3;
 				for (i=1; i<tile_size; i++) {
-					*p = 0xff >> shift;
-					p++;
-					*p = 0xff >> shift;
-					p++;
-					*p = 0xff >> shift;
-					p++;
+					*p++ = tr;
+					*p++ = tg;
+					*p++ = tb;
 				}
 			}
 
@@ -418,24 +458,23 @@ static gboolean render_cb (GtkWidget *canvas)
 
 			/* FIXME: Split out ? */
 			/* No phase problems here. The falling stuff always has a phase of 0 */
-			/* FIXME: Once again, hard-coded bg/fg colours. */
 			bp = gdk_pixbuf_get_pixels (tile);
 			l = gdk_pixbuf_get_rowstride (tile);
 			p = bp + 3;
 			/* Remove the horizontal line... */
 			for (i=1; i<tile_size; i++) {
-				*p++ = 0x00;
-				*p++ = 0x00;
-				*p++ = 0x00;
+				*p++ = br;
+				*p++ = bg;
+				*p++ = bb;
 			}
 			j = tile_size - 1 - ((x + 1)*(tile_size - 1))/(NFRAMESMOVED);
 			downoffsets[x] = j;
 			p = bp + j*l + 3;
 			/* ...and redraw it in the correct place. */
 			for (i=1; i<tile_size; i++) {
-				*p++ = 0xff;
-				*p++ = 0xff;
-				*p++ = 0xff;
+				*p++ = r;
+				*p++ = g;
+				*p++ = b;
 			}
 
 			gdk_pixbuf_composite (file_pixbuf, tile, 1, 1, ftile_size,
@@ -473,15 +512,14 @@ static gboolean render_cb (GtkWidget *canvas)
 
 			/* FIXME: Split out ? */
 			/* No phase problems here. The falling stuff always has a phase of 0 */
-			/* FIXME: Once again, hard-coded bg/fg colours. */
 			bp = gdk_pixbuf_get_pixels (tile);
 			l = gdk_pixbuf_get_rowstride (tile);
 			p = bp + l;
 			/* Remove the vertical line... */
 			for (i=1; i<tile_size; i++) {
-				*p++ = 0x00;
-				*p++ = 0x00;
-				*p   = 0x00;
+				*p++ = br;
+				*p++ = bg;
+				*p   = bb;
 				p   += l - 2;
 			}
 			j = ((x + 1)*(tile_size - 1))/(NFRAMESMOVED);
@@ -489,9 +527,9 @@ static gboolean render_cb (GtkWidget *canvas)
 			p = bp + l + 3*j;
 			/* ...and redraw it in the correct place. */
 			for (i=1; i<tile_size; i++) {
-				*p++ = 0xff;
-				*p++ = 0xff;
-				*p   = 0xff;
+				*p++ = r;
+				*p++ = g;
+				*p   = b;
 				p   += l - 2;
 			}
 
@@ -557,29 +595,6 @@ void change_theme (gchar *newtheme)
 	}
 }
 
-void resize_graphics (void)
-{
-	int size;
-
-	size = drawing_area_width/board_width;
-
-	if (tile_size != size) {
-
-		tile_size = size;
-
-		start_renderer ();
-	}
-}
-
-gboolean configure_cb (GtkWidget *canvas, GdkEventConfigure *event)
-{
-	canvaswidget = canvas;
-	drawing_area_width = event->width;
-	resize_graphics ();
-
-  return FALSE;
-}
-
 static gboolean animation_timer (void)
 {
 	static float speed = 1.0;
@@ -620,7 +635,10 @@ static gboolean animation_timer (void)
 				draw_ball (canvaswidget, p, i, j);
 				break;				
 			case ANI_DESTROY:
-				p->frame++;
+				if (fast_animation)
+					p->frame = MOVEDFRAMESOFS;
+				else
+					p->frame++;
 				if (p->frame < DESTFRAMESOFS) {
 					p->frame = DESTFRAMESOFS;
 				} else if (p->frame < MOVEDFRAMESOFS) {
@@ -635,7 +653,11 @@ static gboolean animation_timer (void)
 				break;				
 			case ANI_MOVE_DOWN:
 				if (game_state == GAME_MOVING_DOWN) {
-					p->frame += speed;
+					if (fast_animation)
+						/* This allows a fast, but not instant, animation. */
+						p->frame = MOVELFRAMESOFS; 
+					else 
+						p->frame += speed;
 					if (p->frame >= MOVELFRAMESOFS) {
 						changestatep = TRUE;
 						p->frame = 0;
@@ -649,7 +671,11 @@ static gboolean animation_timer (void)
 				break;
 			case ANI_MOVE_LEFT:
 				if (game_state == GAME_MOVING_LEFT) {
-					p->frame += speed;
+					if (fast_animation)
+						/* This allows a fast, but not instant, animation. */
+						p->frame = NFRAMES; 					
+					else 
+						p->frame += speed;
 					if (p->frame >= NFRAMES) {
 						changestatep = TRUE;
 						p->frame = 0;
@@ -722,6 +748,47 @@ static gboolean animation_timer (void)
 	return TRUE;
 }
 
+void resize_graphics (void)
+{
+	int size, n, m;
+	static gboolean first_run = TRUE;
+
+	if (first_run) {
+		for (n=0; n<MAX_COLOURS; n++)
+			for (m=0; m<NFRAMES; m++)
+				pixmaps[n][m] = NULL;
+
+		first_run = FALSE;
+	}
+
+	size = drawing_area_width/board_width;
+
+	if (tile_size != size) {
+
+		tile_size = size;
+
+		start_renderer ();
+	}
+}
+
+gboolean configure_cb (GtkWidget *canvas, GdkEventConfigure *event)
+{	
+	static gboolean first_run = TRUE;
+
+	if (first_run) { /* Start the animation timer if necessary. */
+		/* 16 frames/second. */
+		g_timeout_add (62, (GSourceFunc)animation_timer, NULL);
+
+		first_run = FALSE;
+	}
+
+	canvaswidget = canvas;
+	drawing_area_width = event->width;
+	resize_graphics ();
+
+  return FALSE;
+}
+
 void start_spinning (void)
 {
 	int i;
@@ -756,16 +823,3 @@ void stop_spinning (void)
 		list++;
 	}
 }
-
-/* FIXME: Do we need the explicit initialisation function ? */
-void init_pixmaps (void)
-{
-	int n,m;
-
-	/* 16 frames/second. */
-	g_timeout_add (62, (GSourceFunc)animation_timer, NULL);
-
-	for (n=0; n<MAX_COLOURS; n++)
-		for (m=0; m<NFRAMES; m++)
-			pixmaps[n][m] = NULL;
-}
