@@ -6,15 +6,14 @@
  *
  */
 
-/* FIXME: The original didn't have to include this, what has chagned ? */
-#include <libintl.h>
+#include "config.h"
+
 #include <gnome.h>
 
 #include <games-files.h>
 #include <games-gridframe.h>
 #include <games-scores-dialog.h>
-
-#include "config.h"
+#include <games-stock.h>
 
 #include "same-gnome.h"
 
@@ -34,9 +33,12 @@ GtkWidget *application;
 GtkWidget *messagewidget;
 GtkWidget *scorewidget;
 GtkWidget *gridframe = NULL;
-GtkToggleAction *fullscreenaction;
-GtkWidget *undo_widget;
-GtkWidget *redo_widget;
+
+GtkAction *undo_action;
+GtkAction *redo_action;
+GtkAction *fullscreen_action;
+GtkAction *leave_fullscreen_action;
+GtkToggleAction *animation_action;
 
 /* The index for the current theme in the theme list. This shouldn't
  * really be a global variable, but C sucks. */
@@ -53,37 +55,20 @@ static void quit_cb (void)
 void set_message (gint count)
 {
 	gchar *message;
-	gchar *part1;
-	gchar *part2;
 	gint s;
 
-	if (count > 1) {
-		s = calculate_score (count);
-		part1 = g_strdup_printf (ngettext ("%d object selected", 
-																			 "%d objects selected", count), count);
-		part2 = g_strdup_printf (ngettext ("%d point", "%d points", s), s);
-		/* Translators: the previous messages get merged into this 
-		 * format string. */
-		message = g_strdup_printf (_("%s (%s)"), part1, part2);
-		gtk_label_set_text (GTK_LABEL (messagewidget), message);
-		g_free (message);
-	} else {
-		gtk_label_set_text (GTK_LABEL (messagewidget), _("No objects selected"));
+	if (count < 2) {
+		gtk_label_set_text (GTK_LABEL (messagewidget), "");
+		return;
 	}
-}
 
-void set_message_destroyed (gint count)
-{
-	gchar *message;
-	gint s;
-
-	if (count < 3) {
+	if (count == 2) {
 		gtk_label_set_text (GTK_LABEL (messagewidget), _("No points"));
 		return;
 	}
 
 	s = calculate_score (count);
-	message = g_strdup_printf (ngettext ("%d point !", "%d points !", s), s);
+	message = g_strdup_printf (ngettext ("%d point", "%d points", s), s);
 	gtk_label_set_text (GTK_LABEL (messagewidget), message);
 	g_free (message);
 } 
@@ -112,7 +97,7 @@ void  new_frame_ratio (gint board_width, gint board_height)
 
 static void about_cb (GtkWidget *widget)
 {
-  const gchar *authors[] = { "Callum McKenzie", NULL };
+  const gchar * const authors[] = { "Callum McKenzie", NULL };
   
   gtk_show_about_dialog (GTK_WINDOW (application),
 			 "authors", authors,
@@ -146,10 +131,9 @@ static GtkWidget *generate_scores_dialog (void)
 
 void game_over_dialog (gint place)
 {
-  static GtkWidget *baddialog;
+  static GtkWidget *baddialog = NULL;
   static GamesScoresDialog *gooddialog;
 	GtkDialog *dialog;
-  GtkWidget *congratulations;
 	gchar *message;
 
 	if (place == 0) { /* Case 1: It was not a top-ten score. */
@@ -164,7 +148,7 @@ void game_over_dialog (gint place)
 			gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (baddialog),
 																								_("Unfortunately your score did not make the top ten."));
 			gtk_dialog_add_buttons (GTK_DIALOG (baddialog), 
-															GTK_STOCK_QUIT, GTK_RESPONSE_CLOSE,
+															GTK_STOCK_QUIT, GTK_RESPONSE_REJECT,
 															_("New Game"), GTK_RESPONSE_ACCEPT,
 															NULL);
 			gtk_dialog_set_default_response (GTK_DIALOG (baddialog), GTK_RESPONSE_ACCEPT);
@@ -172,37 +156,21 @@ void game_over_dialog (gint place)
 		dialog = GTK_DIALOG (baddialog);
   } else { /* Case 2: It was a top ten score. */
 		if (gooddialog) {
+			games_scores_dialog_set_category (gooddialog, 
+																				scorenames[game_size - SMALL]);
 			gtk_window_present (GTK_WINDOW (gooddialog));
 		} else {
 			/* We build two, slightly different, high score dialogs. Once here and
 			 * once for the scores menu item. */
 			gooddialog = GAMES_SCORES_DIALOG (generate_scores_dialog ());
 			
-			/* This is a bit evil, the dialog doesn't quite suit, so
-			 * we take a machete to it. */
-			gtk_container_foreach (GTK_CONTAINER (GTK_DIALOG (gooddialog)->action_area),
-														 (GtkCallback) (gtk_widget_destroy), NULL);
-			gtk_dialog_add_buttons (GTK_DIALOG (gooddialog), 
-															GTK_STOCK_QUIT, GTK_RESPONSE_CLOSE,
-															_("New Game"), GTK_RESPONSE_ACCEPT,
-															NULL);
-			/* FIXME: This doesn't seem to do the right thing. */
-			gtk_dialog_set_default_response (GTK_DIALOG (gooddialog), 
-																			 GTK_RESPONSE_ACCEPT);
-
+			games_scores_dialog_set_buttons (gooddialog, 
+																			 GAMES_SCORES_QUIT_BUTTON |
+																			 GAMES_SCORES_NEW_GAME_BUTTON); 
 			message = g_strdup_printf ("<b>%s</b>\n\n%s", _("Congratulations!"),
-																 _("Your score has made the top 10."));
-			congratulations = gtk_label_new (message);
+																 _("Your score has made the top ten."));
+			games_scores_dialog_set_message (gooddialog, message);
 			g_free (message);
-			gtk_label_set_use_markup (GTK_LABEL (congratulations), TRUE);
-			gtk_label_set_justify (GTK_LABEL (congratulations), 
-														 GTK_JUSTIFY_CENTER);
-			gtk_box_pack_start (GTK_BOX (GTK_DIALOG (gooddialog)->vbox),
-													congratulations,
-													FALSE, FALSE, 5);
-			gtk_box_pack_start (GTK_BOX (GTK_DIALOG (gooddialog)->vbox),
-													gtk_hseparator_new (),
-													FALSE, FALSE, 5);
 
 			gtk_widget_show_all (GTK_WIDGET (gooddialog));
 		}
@@ -211,7 +179,7 @@ void game_over_dialog (gint place)
 	}
 
 	switch (gtk_dialog_run (dialog)) {
-	case GTK_RESPONSE_CLOSE:
+	case GTK_RESPONSE_REJECT:
 		quit_cb ();
 		break;
 	case GTK_RESPONSE_ACCEPT:
@@ -237,6 +205,8 @@ static void change_theme_cb (GtkTreeSelection *selection)
 	gtk_tree_model_get (model, &iter, 1, &filename, -1);
 	
 	change_theme (filename);
+
+	g_free (filename);
 }
 
 static void fill_list (gchar *name, GtkListStore *list)
@@ -250,10 +220,11 @@ static void fill_list (gchar *name, GtkListStore *list)
 	theme_index_counter++;
 
 	/* We strip the final suffix for the displayed name. */
-	uiname = g_strdup (name);
-	suffix = g_strrstr (uiname, ".");
+	suffix = g_strrstr (name, ".");
 	if (suffix)
-		*suffix = '\0';
+		uiname = g_strndup (name, suffix - name);
+	else
+		uiname = g_strdup (name);
 
 	/* Capitalise the first letter. This won't work wonderfully in
 	 * general, but it will be just fine for the themes we currently
@@ -261,10 +232,10 @@ static void fill_list (gchar *name, GtkListStore *list)
 	*uiname = g_unichar_toupper (*uiname);
 
 	gtk_list_store_append (list, &iter);
-	gtk_list_store_set (list, &iter, 0, uiname, 1, g_strdup (name), -1);
-
-
+	gtk_list_store_set (list, &iter, 0, uiname, 1, name, -1);
 
+	/* the store keeps a copy */
+	g_free (uiname);
 }
 
 static void theme_cb (void)
@@ -286,6 +257,8 @@ static void theme_cb (void)
 																					GTK_DIALOG_NO_SEPARATOR,
 																					GTK_STOCK_CLOSE, GTK_RESPONSE_ACCEPT,
 																					NULL);
+		gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
+		gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 2);
 		gtk_dialog_set_default_response (GTK_DIALOG (dialog),
 																		 GTK_RESPONSE_ACCEPT);
 		g_signal_connect (G_OBJECT (dialog), "response",
@@ -294,9 +267,12 @@ static void theme_cb (void)
 												G_CALLBACK (gtk_widget_hide), NULL);
 		
 		scroll = gtk_scrolled_window_new (NULL, NULL);
+		gtk_container_set_border_width (GTK_CONTAINER (scroll), 5);
 		gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scroll),
 																		GTK_POLICY_AUTOMATIC,
 																		GTK_POLICY_AUTOMATIC);
+		gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scroll),
+		                                     GTK_SHADOW_ETCHED_IN);
 		gtk_widget_set_size_request (scroll, 250, 250);
 		gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), scroll,
 												TRUE, TRUE, 0);
@@ -311,6 +287,8 @@ static void theme_cb (void)
 		g_object_unref (filelist);
 
 		listview = gtk_tree_view_new_with_model (GTK_TREE_MODEL (list));
+		g_object_unref (list);
+
 		gtk_container_add (GTK_CONTAINER (scroll), listview);
 		column = gtk_tree_view_column_new_with_attributes (_("Theme"),
 																											 gtk_cell_renderer_text_new (),
@@ -320,8 +298,9 @@ static void theme_cb (void)
 		selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (listview));
 		gtk_tree_selection_set_mode (selection, GTK_SELECTION_BROWSE);
 		if (current_theme_index >= 0) {
-			gtk_tree_selection_select_path (selection, 
-																			gtk_tree_path_new_from_indices (current_theme_index, -1));
+			GtkTreePath *path = gtk_tree_path_new_from_indices (current_theme_index, -1);
+			gtk_tree_selection_select_path (selection, path);
+			gtk_tree_path_free (path);
 		} else {
 			gtk_tree_selection_unselect_all (selection);
 		}
@@ -333,23 +312,37 @@ static void theme_cb (void)
 	}
 }
 
-static void fullscreen_cb (GtkToggleAction *action)
+static void set_fullscreen_actions (gboolean is_fullscreen)
 {
-  if (gtk_toggle_action_get_active (action)) {
+	gtk_action_set_sensitive (leave_fullscreen_action, is_fullscreen);
+	gtk_action_set_visible (leave_fullscreen_action, is_fullscreen);
+
+	gtk_action_set_sensitive (fullscreen_action, !is_fullscreen);
+	gtk_action_set_visible (fullscreen_action, !is_fullscreen);
+}
+
+static void fullscreen_cb (GtkAction *action)
+{
+  if (action == fullscreen_action) {
     gtk_window_fullscreen (GTK_WINDOW (application));
   } else {
     gtk_window_unfullscreen (GTK_WINDOW (application));
   }
 }
 
+static void animation_cb (GtkToggleAction *action)
+{
+	fast_animation_enable (gtk_toggle_action_get_active (action));
+}
+
 /* Just in case something else takes us to/from fullscreen. */
 static void window_state_cb (GtkWidget *widget, GdkEventWindowState *event)
 {
   if (!(event->changed_mask & GDK_WINDOW_STATE_FULLSCREEN))
     return;
     
-  gtk_toggle_action_set_active (fullscreenaction,
-				event->new_window_state & GDK_WINDOW_STATE_FULLSCREEN);
+	set_fullscreen_actions (event->new_window_state & 
+														GDK_WINDOW_STATE_FULLSCREEN);
 }
 
 static void scores_cb (void)
@@ -431,17 +424,18 @@ const GtkActionEntry actions[] = {
   { "SizeMenu", NULL, N_("_Size") },
   { "HelpMenu", NULL, N_("_Help") },
 
-  { "NewGame", GTK_STOCK_NEW, N_("_New Game"), "<control>N", NULL, G_CALLBACK (new_game_cb) },
-  { "Scores", NULL, N_("_Scores..."), NULL, NULL, G_CALLBACK (scores_cb) },
-  { "UndoMove", GTK_STOCK_UNDO, N_("_Undo Move"), "<control>Z", NULL, G_CALLBACK (undo_cb) },
-  { "RedoMove", GTK_STOCK_REDO, N_("_Redo Move"), "<shift><control>Z", NULL, G_CALLBACK (redo_cb) },
+  { "NewGame", GAMES_STOCK_NEW_GAME, NULL, NULL, NULL, G_CALLBACK (new_game_cb) },
+  { "Scores", GAMES_STOCK_SCORES, NULL, NULL, NULL, G_CALLBACK (scores_cb) },
+  { "UndoMove", GAMES_STOCK_UNDO_MOVE, NULL, NULL, NULL, G_CALLBACK (undo_cb) },
+  { "RedoMove", GAMES_STOCK_REDO_MOVE, NULL, NULL, NULL, G_CALLBACK (redo_cb) },
   { "Quit", GTK_STOCK_QUIT, NULL, NULL, NULL, G_CALLBACK (quit_cb) },
 
+	{ "Fullscreen", GAMES_STOCK_FULLSCREEN, NULL, NULL, NULL, G_CALLBACK (fullscreen_cb) },
+	{ "LeaveFullscreen", GAMES_STOCK_LEAVE_FULLSCREEN, NULL, NULL, NULL, G_CALLBACK (fullscreen_cb) },
   { "Theme", NULL, N_("_Theme..."), NULL, NULL, G_CALLBACK (theme_cb) },
 
-  { "Contents", GTK_STOCK_HELP, N_("_Contents"), "F1", NULL, G_CALLBACK (help_cb) },
-  {"About", GTK_STOCK_ABOUT, NULL, NULL, NULL, G_CALLBACK (about_cb)
-}
+  { "Contents", GAMES_STOCK_CONTENTS, NULL, NULL, NULL, G_CALLBACK (help_cb) },
+  {"About", GTK_STOCK_ABOUT, NULL, NULL, NULL, G_CALLBACK (about_cb) }
 };
 
 const GtkRadioActionEntry radio_actions[] = {
@@ -451,10 +445,10 @@ const GtkRadioActionEntry radio_actions[] = {
 };
 
 const GtkToggleActionEntry toggle_actions[] = {
-  { "Fullscreen", NULL, N_("_Fullscreen"), NULL, NULL, G_CALLBACK (fullscreen_cb) }
+	{ "Animation", NULL, N_("_Fast Animation"), NULL, NULL, G_CALLBACK (animation_cb) }
 };
 
-const char *ui_description =
+const char ui_description[] =
 "<ui>"
 "  <menubar name='MainMenu'>"
 "    <menu action='GameMenu'>"
@@ -468,6 +462,8 @@ const char *ui_description =
 "    </menu>"
 "    <menu action='ViewMenu'>"
 "      <menuitem action='Fullscreen'/>"
+"      <menuitem action='LeaveFullscreen'/>"
+"      <menuitem action='Animation'/>"
 "      <menuitem action='Theme'/>"
 "    </menu>"
 "    <menu action='SizeMenu'>"
@@ -490,9 +486,6 @@ void build_gui (void)
   GtkUIManager *ui_manager;
   GtkActionGroup *action_group;
   
-  /* FIXME: Will need to initialise the pixmap array to zero. */
-  init_pixmaps ();
-  
 	/* FIXME: Can we get a better name for the icon? */
 	gtk_window_set_default_icon_name ("gnome-gsame");
 
@@ -514,26 +507,30 @@ void build_gui (void)
   gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
   gtk_action_group_add_actions (action_group, actions, G_N_ELEMENTS (actions),
 				NULL);
-	/* FIXME: This doesn't set the radio button correctly. Try setting the
-	 * game to medium, relaunching and then looking at the size menu. */
   gtk_action_group_add_radio_actions (action_group, radio_actions, 
 				      G_N_ELEMENTS (radio_actions), 
-				      game_size - SMALL, 
+				      game_size, 
 				      G_CALLBACK (size_change_cb), 
 				      NULL);
   gtk_action_group_add_toggle_actions (action_group, toggle_actions,
-				       G_N_ELEMENTS (toggle_actions), NULL);
+                                       G_N_ELEMENTS (toggle_actions), NULL);	
 
-  fullscreenaction = GTK_TOGGLE_ACTION (gtk_action_group_get_action (action_group, "Fullscreen"));
+	undo_action = gtk_action_group_get_action (action_group, "UndoMove");
+	redo_action = gtk_action_group_get_action (action_group, "RedoMove");
+  fullscreen_action = gtk_action_group_get_action (action_group, "Fullscreen");
+  leave_fullscreen_action = gtk_action_group_get_action (action_group, 
+																												 "LeaveFullscreen");
+	animation_action = GTK_TOGGLE_ACTION (gtk_action_group_get_action (action_group, "Animation"));
+	set_fullscreen_actions (FALSE);
+
+	gtk_toggle_action_set_active (animation_action,
+																gconf_client_get_bool (gcclient, 
+																											 GCONF_FAST_ANIMATION_KEY,
+																											 NULL));
   
   ui_manager = gtk_ui_manager_new ();
   gtk_ui_manager_insert_action_group (ui_manager, action_group, 1);
   gtk_ui_manager_add_ui_from_string (ui_manager, ui_description, -1, NULL);
-
-	undo_widget = gtk_ui_manager_get_widget (ui_manager, 
-																					 "/MainMenu/GameMenu/UndoMove");
-	redo_widget = gtk_ui_manager_get_widget (ui_manager, 
-																					 "/MainMenu/GameMenu/RedoMove");
   
   gtk_window_add_accel_group (GTK_WINDOW (application),
 			      gtk_ui_manager_get_accel_group (ui_manager));
@@ -585,6 +582,6 @@ void build_gui (void)
 
 void set_undoredo_sensitive (gboolean undo, gboolean redo)
 {
-	gtk_widget_set_sensitive (undo_widget, undo);
-	gtk_widget_set_sensitive (redo_widget, redo);
+	gtk_action_set_sensitive (undo_action, undo);
+	gtk_action_set_sensitive (redo_action, redo);
 }
